import arcade

import arcade.gui
from arcade.gui import UIFlatButton, UIGhostFlatButton, UIManager
from arcade.gui.style import UIStyle


class MyView(arcade.View):
    def __init__(self, window: arcade.Window):
        super().__init__()

        self.window = window
        self.ui_manager = UIManager(window)

    def on_draw(self):
        arcade.start_render()
        self.ui_manager.on_draw()

    def on_show_view(self):
        arcade.set_background_color(arcade.color.BLACK)
        self.ui_manager.purge_ui_elements()
        self.ui_manager.enable()

        flat = UIFlatButton(
            "Hello world",
            center_x=200,
            center_y=self.window.height // 2,
            min_size=(200, 40),
        )
        flat.set_style_attrs(
            font_color=arcade.color.WHITE,
            font_color_hover=arcade.color.WHITE,
            font_color_press=arcade.color.WHITE,
            bg_color=(51, 139, 57),
            bg_color_hover=(51, 139, 57),
            bg_color_press=(28, 71, 32),
            border_color=(51, 139, 57),
            border_color_hover=arcade.color.WHITE,
            border_color_press=arcade.color.WHITE,
        )
        self.ui_manager.add_ui_element(flat)

        # creates a new class, which will match the id
        UIStyle.default_style().set_class_attrs(
            "right_button",
            font_color=arcade.color.WHITE,
            font_color_hover=arcade.color.WHITE,
            font_color_press=arcade.color.WHITE,
            bg_color=(135, 21, 25),
            bg_color_hover=(135, 21, 25),
            bg_color_press=(122, 21, 24),
            border_color=(135, 21, 25),
            border_color_hover=arcade.color.WHITE,
            border_color_press=arcade.color.WHITE,
        )
        self.ui_manager.add_ui_element(
            UIGhostFlatButton(
                "Hello world",
                center_x=600,
                center_y=self.window.height // 2,
                min_size=(200, 40),
                id="right_button",
            )
        )

    def on_hide_view(self):
        self.ui_manager.disable()


if __name__ == "__main__":
    window = arcade.Window(title="ARCADE_GUI")
    window.show_view(MyView(window))
    arcade.run()
